==> rest-sdk-java-generator-0.8.0-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/operation/SdkPageNumberPaginationOperation.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.operation;

import com.mulesoft.connectivity.rest.commons.api.operation.paging.PageNumberPagingProvider;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.operation.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.exception.TemplatingException;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.SdkConnector;

import java.nio.file.Path;
import java.util.ArrayList;
import java.util.List;

import com.squareup.javapoet.CodeBlock;
import com.squareup.javapoet.ParameterSpec;

public class SdkPageNumberPaginationOperation extends AbstractSdkPaginationOperation {

  public SdkPageNumberPaginationOperation(Path outputDir, ConnectorModel connectorModel, SdkConnector sdkConnector,
                                          ConnectorOperation operation, RestSdkRunConfiguration runConfiguration)
      throws TemplatingException {
    super(outputDir, connectorModel, sdkConnector, operation, runConfiguration);
  }

  @Override
  public CodeBlock getPagingMethodOperation() throws TemplatingException {
    CodeBlock.Builder block = CodeBlock.builder();
    block.add(
              "return new $T($S, $S, $L, requestFactory, getExpressionLanguage(), $S,"
                  + " resolveDefaultResponseMediaType(config), $L, $L,  overrides.getResponseTimeoutAsMillis())",
              getPagingProviderClass(),
              getPagination().getPaginationParameter(),
              getPagination().getPageCountExpression(),
              getPagingParameter().getJavaName(),
              getPayloadExpression(),
              PARAMETER_BINDINGS_NAME,
              CUSTOM_PARAMETER_BINDINGS_NAME);
    addResponseBindings(block);
    return block.build();
  }

  @Override
  protected List<ParameterSpec> getPagingParametersAsParameterSpecs() throws TemplatingException {
    List<ParameterSpec> parameterSpecs = new ArrayList<>();
    ParameterSpec parameterSpecBuilder1 = getPagingParameter().generateParameterParameter(false).build();
    parameterSpecs.add(parameterSpecBuilder1);
    return parameterSpecs;
  }

  @Override
  public Class<?> getPagingProviderClass() {
    return PageNumberPagingProvider.class;
  }
}

==> rest-sdk-java-generator-0.12.0-20250401.143830-3-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/operation/SdkPageNumberPaginationOperation.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.operation;

import com.mulesoft.connectivity.rest.commons.api.operation.paging.PageNumberPagingProvider;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.operation.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.exception.TemplatingException;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.SdkConnector;

import java.nio.file.Path;

import com.squareup.javapoet.CodeBlock;

public class SdkPageNumberPaginationOperation extends AbstractSdkPaginationOperation {

  public SdkPageNumberPaginationOperation(Path outputDir, ConnectorModel connectorModel, SdkConnector sdkConnector,
                                          ConnectorOperation operation, RestSdkRunConfiguration runConfiguration)
      throws TemplatingException {
    super(outputDir, connectorModel, sdkConnector, operation, runConfiguration);
  }

  @Override
  public CodeBlock getPagingMethodOperation() throws TemplatingException {
    CodeBlock.Builder block = CodeBlock.builder();
    block.add(
              "return new $T($S, $S, $L, requestFactory, $L, $S,"
                  + " resolveDefaultResponseMediaType(config), $L, $L,  overrides.getResponseTimeoutAsMillis())",
              getPagingProviderClass(),
              getPagination().getPaginationParameter(),
              getPagination().getPageCountExpression(),
              DEFAULT_PAGING_PARAMETER,
              EXPRESSION_LANGUAGE,
              getPayloadExpression(),
              PARAMETER_BINDINGS_NAME,
              CUSTOM_PARAMETER_BINDINGS_NAME);
    addResponseBindings(block);
    return block.build();
  }

  @Override
  protected boolean externalizePagingParam() {
    return true;
  }

  @Override
  public Class<?> getPagingProviderClass() {
    return PageNumberPagingProvider.class;
  }
}
